You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@arrow.apache.org by fs...@apache.org on 2020/05/04 12:09:43 UTC

[arrow] branch master updated: ARROW-8687: [Java] Remove references to io.netty.buffer.ArrowBuf

This is an automated email from the ASF dual-hosted git repository.

fsaintjacques pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/arrow.git


The following commit(s) were added to refs/heads/master by this push:
     new 191b56f  ARROW-8687: [Java] Remove references to io.netty.buffer.ArrowBuf
191b56f is described below

commit 191b56f0333d00e8fb3b822b9a8fe8fb426f56b6
Author: Ryan Murray <ry...@dremio.com>
AuthorDate: Mon May 4 08:09:17 2020 -0400

    ARROW-8687: [Java] Remove references to io.netty.buffer.ArrowBuf
    
    Some references to `io.netty.buffer.ArrowBuf` were missed off
    in ARROW-8229. This cleans up the last remaining references.
    
    Closes #7093 from rymurr/ARROW-8687
    
    Authored-by: Ryan Murray <ry...@dremio.com>
    Signed-off-by: François Saint-Jacques <fs...@gmail.com>
---
 .../src/test/java/org/apache/arrow/memory/TestLargeArrowBuf.java     | 4 +---
 .../java/org/apache/arrow/memory/TestNettyAllocationManager.java     | 2 --
 .../src/test/java/org/apache/arrow/vector/TestLargeVector.java       | 5 ++---
 python/pyarrow/jvm.py                                                | 4 ++--
 4 files changed, 5 insertions(+), 10 deletions(-)

diff --git a/java/memory/src/test/java/org/apache/arrow/memory/TestLargeArrowBuf.java b/java/memory/src/test/java/org/apache/arrow/memory/TestLargeArrowBuf.java
index 2160930..7d85187 100644
--- a/java/memory/src/test/java/org/apache/arrow/memory/TestLargeArrowBuf.java
+++ b/java/memory/src/test/java/org/apache/arrow/memory/TestLargeArrowBuf.java
@@ -19,10 +19,8 @@ package org.apache.arrow.memory;
 
 import static org.junit.Assert.assertEquals;
 
-import io.netty.buffer.ArrowBuf;
-
 /**
- * Integration test for large (more than 2GB) {@link io.netty.buffer.ArrowBuf}.
+ * Integration test for large (more than 2GB) {@link org.apache.arrow.memory.ArrowBuf}.
  * To run this test, please make sure there is at least 4GB memory in the system.
  * <p>
  *   Please note that this is not a standard test case, so please run it by manually invoking the
diff --git a/java/memory/src/test/java/org/apache/arrow/memory/TestNettyAllocationManager.java b/java/memory/src/test/java/org/apache/arrow/memory/TestNettyAllocationManager.java
index 5a70067..5c5baad 100644
--- a/java/memory/src/test/java/org/apache/arrow/memory/TestNettyAllocationManager.java
+++ b/java/memory/src/test/java/org/apache/arrow/memory/TestNettyAllocationManager.java
@@ -24,8 +24,6 @@ import static org.junit.Assert.assertTrue;
 
 import org.junit.Test;
 
-import io.netty.buffer.ArrowBuf;
-
 /**
  * Test cases for {@link NettyAllocationManager}.
  */
diff --git a/java/vector/src/test/java/org/apache/arrow/vector/TestLargeVector.java b/java/vector/src/test/java/org/apache/arrow/vector/TestLargeVector.java
index e128d40..c33acb6 100644
--- a/java/vector/src/test/java/org/apache/arrow/vector/TestLargeVector.java
+++ b/java/vector/src/test/java/org/apache/arrow/vector/TestLargeVector.java
@@ -20,13 +20,12 @@ package org.apache.arrow.vector;
 import static org.junit.Assert.assertArrayEquals;
 import static org.junit.Assert.assertEquals;
 
+import org.apache.arrow.memory.ArrowBuf;
 import org.apache.arrow.memory.BufferAllocator;
 import org.apache.arrow.memory.RootAllocator;
 
-import io.netty.buffer.ArrowBuf;
-
 /**
  * Integration test for a vector with a large (more than 2GB) {@link io.netty.buffer.ArrowBuf} as
  * the data buffer.
  * To run this test, please make sure there is at least 4GB free memory in the system.
  * <p>
@@ -20,13 +20,12 @@ package org.apache.arrow.vector;
 /**
- * Integration test for a vector with a large (more than 2GB) {@link io.netty.buffer.ArrowBuf} as
+ * Integration test for a vector with a large (more than 2GB) {@link org.apache.arrow.memory.ArrowBuf} as
  * the data buffer.
  * To run this test, please make sure there is at least 4GB free memory in the system.
diff --git a/python/pyarrow/jvm.py b/python/pyarrow/jvm.py
index 650b8b2..8085951 100644
--- a/python/pyarrow/jvm.py
+++ b/python/pyarrow/jvm.py
@@ -30,12 +30,12 @@ import pyarrow as pa
 
 def jvm_buffer(arrowbuf):
     """
     Construct an Arrow buffer from io.netty.buffer.ArrowBuf
 
     Parameters
     ----------
 
-    arrowbuf: io.netty.buffer.ArrowBuf
+    arrowbuf: org.apache.arrow.memory.ArrowBuf
         Arrow Buffer representation on the JVM.
 
     Returns
@@ -30,12 +30,12 @@ import pyarrow as pa
 def jvm_buffer(arrowbuf):
     """
-    Construct an Arrow buffer from io.netty.buffer.ArrowBuf
+    Construct an Arrow buffer from org.apache.arrow.memory.ArrowBuf
 
     Parameters